.. _pscripts_documentation:

``p*`` Scripts Documentation
============================

Command line programs (``p*`` scripts) included with :app:`Pyramid`.

.. toctree::
   :maxdepth: 1
   :glob:

   *
